Calibration
==========

The calibration module provides tools for geometric calibration of robots.

**New in v0.3.0:**
- Modular code organization with separate config, parameter, and data loader modules
- Significant code reduction (58% fewer lines in calibration_tools)
- Enhanced maintainability and extensibility

base_calibration
---------------
.. automodule:: figaroh.calibration.base_calibration
   :members:
   :undoc-members:
   :show-inheritance:

calibration_tools
---------------
.. automodule:: figaroh.calibration.calibration_tools
   :members:
   :undoc-members:
   :show-inheritance:

Configuration Management (New in v0.3.0)
----------------------------------------
.. automodule:: figaroh.calibration.config
   :members:
   :undoc-members:
   :show-inheritance:

Parameter Management (New in v0.3.0)
------------------------------------
.. automodule:: figaroh.calibration.parameter
   :members:
   :undoc-members:
   :show-inheritance:

Data Loading (New in v0.3.0)
----------------------------
.. automodule:: figaroh.calibration.data_loader
   :members:
   :undoc-members:
   :show-inheritance:
